@@ -552,9 +552,16 @@ class ValidatorMixin:
         otherwise, the whole dict is returned
         """
         props = self.get(tabname, "schemas").build()["properties"]
-        units = {
-            dim: units for dim, data in props.items() if (units := data.get("units"))
-        }
+        # python >= 3.8 only
+        # units = {
+        #     dim: units for dim, data in props.items() if (units := data.get("units"))
+        # }
+        units = {}
+        for dim, data in props.items():
+            _units = data.get("units")
+            if _units:
+                units[dim] = _units
+
         if key:
             return units[key]
         return units
