@@ -273,7 +273,7 @@ def test_VData_00():
     # create dummy data
     data._data["test"] = pd.DataFrame(
         {
-            "id": {7: 0, 1: 1, 2: 5},
+            "id": {7: 0, 1: 1, 2: 1},
             "name": {7: "Doe", 1: "Fante", 2: "Mercury"},
             "firstname": {7: "John", 2: "Freddy", 1: "Richard"},
             "age": {7: "42", 1: 22},
@@ -286,6 +286,7 @@ def test_VData_00():
             "'42' is not of type 'integer'",
             "'42' is not of type 'null'",
         ],
+        ("id", "?"): ["value {1} is not unique"],
         ("life_nb", 0): ["5 is greater than the maximum of 4"],
         ("life_nb", 1): ["'hg' is not of type 'integer'"],
         ("life_nb", 2): ["15 is greater than the maximum of 4"],
@@ -698,3 +699,25 @@ def test_IVData_07_failing_units(datadir):
             ("test_mass_lb", "?"): "cannot convert some values to numeric",
         }
     }
+
+
+def test_IVData_08_multi_cols_uniqueness(datadir):
+    """check units"""
+    indir, outdir = datadir
+    data_si = IVData()
+    data_si.read(os.path.join(indir, "test_06_multi-columns_uniqueness.ini"))
+    # -------------------------------------------------------------------------
+    # read and check schema
+    data_si.read_schema(
+        os.path.join(indir, "test_05_SI.yaml"),
+        os.path.join(indir, "test_06_data.yaml"),
+    )
+    rep = data_si.validate()
+    assert rep == {
+        "asm_failing": {
+            ("another", "?"): ["value {1.0} is not unique"],
+            ("rail_tag & x_loc & block_label", "?"): [
+                "value {'RBL11 & 3500 & RECARO1'} is not unique"
+            ],
+        }
+    }
